<?php

namespace App\Http\Controllers\Admin\Actor;

use App\Http\Controllers\Controller;
use App\Models\Actor;
use Carbon\Carbon;
use Illuminate\Http\Request;
use RealRashid\SweetAlert\Facades\Alert;

class ActorController extends Controller{
    // actor list page
    public function index(){
        $page_data['actor'] = Actor::paginate(10);
        return view('admin.actor.index', $page_data);
    }

    // create actor
    public function create(){
        $page_data['actor'] = Actor::get();
        return view('admin.actor.create', $page_data);
    }

    // create/store actor
    public function store(Request $request){
        $validatedData = $request->validate([
            'name' => 'required|max:20'
        ]);
        if($request->image){
            $image_name = time().'.jpg';
        }else{
            $image_name = 0;
        }
        $data = array(
            'name' => $request->name,
            'bio_link' => $request->bio_link,
            'image' => $image_name,
            'created_at' => Carbon::now(),
            'updated_at' => Carbon::now(),
        );
        $insert = Actor::insert($data);
        if($insert){
            if($request->image){
                $request->image->storeAs('public/actor',$image_name);
            }
            Alert::success(get_phrase('Success'), get_phrase('Actor Created Successfully'));
            return redirect()->back();
        }else{
            Alert::error(get_phrase('Retry'), get_phrase('Somthing Wrong'));
            return redirect()->back();
        }
    }

    // edit actor page
    public function edit($id){
        $page_data['actor_details'] = Actor::where('id', $id)->first();
        return view('admin.actor.edit', $page_data);
    }

    // update actor
    public function update(Request $request, $id){
        $validatedData = $request->validate([
            'name' => 'required|max:20'
        ]);
        if($request->image){
            $image_name = time().'.jpg';
            $path = $request->image->storeAs('public/actor',$image_name);
        }else{
            $image_name = $request->old_image;
        }
        $data = array(
            'name' => $request->name,
            'bio_link' => $request->bio_link,
            'image' => $image_name,
            'updated_at' => Carbon::now(),
        );
        $update = Actor::where('id', $id)->update($data);
        if($update){
            if($request->image){
                if(file_exists('storage/actor/'.$request->old_image)){
                    unlink('storage/actor/'.$request->old_image);
                }
                $request->image->storeAs('public/actor',$image_name);
            }
            Alert::success(get_phrase('Success'), get_phrase('Actor Updated Successfully'));
            return redirect()->back();
        }else{
            Alert::error(get_phrase('Retry'), get_phrase('Somthing Wrong'));
            return redirect()->back();
        }
    }

    // delete actor
    public function delete($id){
        $actor = Actor::where('id', $id);
        if(file_exists('storage/actor/'.$actor->first()->image)){
            unlink('storage/actor/'.$actor->first()->image);
        }
        $delete = $actor->delete();
        if($delete){
            Alert::info(get_phrase('Success'), get_phrase('Actor Deleted Successfully'));
            return redirect()->back();
        }else{
            Alert::error(get_phrase('Retry'), get_phrase('Somthing Wrong'));
            return redirect()->back();
        }
    }
}
