<?php

namespace App\Http\Controllers\Admin\Category;

use App\Http\Controllers\Controller;
use App\Models\Category;
use Carbon\Carbon;
use Illuminate\Http\Request;
use RealRashid\SweetAlert\Facades\Alert;

class CategoryController extends Controller{
    // category list view
    public function index(){
        $page_data['categories'] = Category::paginate(10);
        return view('admin.category.index', $page_data);
    }

    // create category
    public function create(){
        return view('admin.category.create');
    }

    // store category
    public function store(Request $request){
        $validatedData = $request->validate([
            'name' => 'required|max:50',
        ]);
        $data = array(
            'name' => $request->name,
            'created_at' => Carbon::now(),
            'updated_at' => Carbon::now(),
        );
        $insert = Category::insert($data);
        if($insert){
            Alert::success(get_phrase('Success'), get_phrase('Category Created Successfully'));
            return redirect()->back();
        }else{
            Alert::error(get_phrase('Retry'), get_phrase('Somthing Wrong'));
            return redirect()->back();
           
        }
    }

    // edit category
    public function edit($id){
        $page_data['category_details'] = Category::where('id', $id)->first();
        return view('admin.category.edit', $page_data);
    }

    // update category
    public function update(Request $request, $id){
        $validatedData = $request->validate([
            'name' => 'required|max:50',
        ]);
        $data = array(
            'name' => $request->name,
            'updated_at' => Carbon::now(),
        );
        $update = Category::where('id', $id)->update($data);
        if($update){
            Alert::success(get_phrase('Success'), 'Category Updated Successfully');
            return redirect()->back();
        }else{
            Alert::error(get_phrase('Retry'), 'Somthing Wrong');
            return redirect()->back();
        }
    }

    // delete genre
    public function delete($id){
        $category = Category::where('id', $id);
        $delete = $category->delete();
        if($delete){
            Alert::info(get_phrase('Success'), 'Category Deleted Successfully');
            return redirect()->back();
        }else{
            Alert::error(get_phrase('Retry'), 'Somthing wrong');
            return redirect()->back();
        }
    }
}
