<?php

namespace App\Http\Controllers\Admin\Director;

use App\Http\Controllers\Controller;
use App\Models\Director;
use Illuminate\Http\Request;
use Illuminate\Support\Carbon;
use RealRashid\SweetAlert\Facades\Alert;

class DirectorController extends Controller{
    // director list page
    public function index(){
        $page_data['director'] = Director::paginate(10);
        return view('admin.director.index', $page_data);
    }

    // create director
    public function create(){
        return view('admin.director.create');
    }

    // create director
    public function store(Request $request){
        $validatedData = $request->validate([
            'name' => 'required|max:20'
        ]);
        if($request->image){
            $image_name = time().'.jpg';
        }else{
            $image_name = 0;
        }
        $data = array(
            'name' => $request->name,
            'image' => $image_name,
            'created_at' => Carbon::now(),
            'updated_at' => Carbon::now(),
        );
        $insert = Director::insert($data);
        if($insert){
            if($request->image){
                $request->image->storeAs('public/director',$image_name);
            }
            Alert::success(get_phrase('Success'), get_phrase('Director Created Successfully'));
            return redirect()->back();
        }else{
            Alert::error(get_phrase('Retry'), get_phrase('Somthing Wrong'));
            return redirect()->back();
        }
    }

    // edit director page
    public function edit($id){
        $page_data['director_details'] = Director::where('id', $id)->first();
        return view('admin.director.edit', $page_data);
    }

    // update director 
    public function update(Request $request, $id){
        $validatedData = $request->validate([
            'name' => 'required|max:20'
        ]);
        if($request->image){
            $image_name = time().'.jpg';
        }else{
            $image_name = $request->old_image;
        }
        $data = array(
            'name' => $request->name,
            'image' => $image_name,
            'updated_at' => Carbon::now(),
        );
        $update = Director::where('id', $id)->update($data);
        if($update){
            if($request->image){
                if(file_exists('storage/director/'.$request->old_image)){
                    unlink('storage/director/'.$request->old_image);
                }
                $request->image->storeAs('public/director',$image_name);
            }
            Alert::success(get_phrase('Success'), 'Director Updated Successfully');
            return redirect()->back();
        }else{
            Alert::error(get_phrase('Retry'), get_phrase('Somthing Wrong'));
            return redirect()->back();
        }
    }

    // delete director
    public function delete($id){
        $director = Director::where('id', $id);
        if(file_exists('storage/director/'.$director->first()->image)){
            unlink('storage/director/'.$director->first()->image);
        }
        $delete = $director->delete();
        if($delete){
            Alert::info(get_phrase('Success'), get_phrase('Director Deleted Successfully'));
            return redirect()->back();
        }else{
            Alert::error(get_phrase('Retry'), get_phrase('Somthing wrong'));
            return redirect()->back();
        }
    }
}
