<?php

namespace App\Http\Controllers\Admin\Genre;

use App\Http\Controllers\Controller;
use Carbon\Carbon;
use App\Models\Genre;
use Illuminate\Http\Request;
use RealRashid\SweetAlert\Facades\Alert;

class GenreController extends Controller{
    // genre list page
    public function index(){
        $page_data['genre'] = Genre::paginate(10);
        return view('admin.genre.index', $page_data);
    }

    // create genre page
    public function create(){
        return view('admin.genre.create');
    }

    // store genre
    public function store(Request $request){
        $validatedData = $request->validate([
            'name' => 'required|max:50',
        ]);
        $data = array(
            'name' => $request->name,
            'created_at' => Carbon::now(),
            'updated_at' => Carbon::now(),
        );
        $insert = Genre::insert($data);
        if($insert){
            Alert::success(get_phrase('Success'), get_phrase('Genre Created Successfully'));
            return redirect()->back();
        }else{
            Alert::error(get_phrase('Retry'), get_phrase('Somthing Wrong'));
            return redirect()->back();
           
        }
        
    }

    // edit genre page
    public function edit($id){
        $page_data['genre_details'] = Genre::where('id', $id)->first();
        return view('admin.genre.edit', $page_data);
    }

    // update genre
    public function update(Request $request, $id){
        $validatedData = $request->validate([
            'name' => 'required|max:50',
        ]);
        $data = array(
            'name' => $request->name,
            'updated_at' => Carbon::now(),
        );
        $update = Genre::where('id', $id)->update($data);
        if($update){
            Alert::success(get_phrase('Success'), 'Genre Updated Successfully');
            return redirect()->back();
        }else{
            Alert::error(get_phrase('Retry'), 'Somthing Wrong');
            return redirect()->back();
        }
    }

    // delete genre
    public function delete($id){
        $genre = Genre::where('id', $id);
        $delete = $genre->delete();
        if($delete){
            Alert::info(get_phrase('Success'), 'Genre Deleted Successfully');
            return redirect()->back();
        }else{
            Alert::error(get_phrase('Retry'), 'Somthing wrong');
            return redirect()->back();
        }
    }
}
