<?php

namespace App\Http\Controllers\Admin\Movie;

use App\Http\Controllers\Controller;
use App\Models\Actor;
use App\Models\Category;
use App\Models\Country;
use App\Models\Director;
use App\Models\Genre;
use App\Models\Movie;
use Carbon\Carbon;
use Validator;
use Illuminate\Http\Request;
use RealRashid\SweetAlert\Facades\Alert;

class MovieController extends Controller{
    // movie list page
    public function index(){
        $page_data['movie'] = Movie::paginate(10);
        return view('admin.movie.index', $page_data);
    }

    // movie create page
    public function create(){
        $page_data['genre'] = Genre::get();
        $page_data['director'] = Director::get();
        $page_data['actor'] = Actor::get();
        $page_data['country'] = Country::get();
        $page_data['category'] = Category::get();
        return view('admin.movie.create', $page_data);
    }

    // movie store
    public function store(Request $request){
        $validatedData   = $request->validate([
            'title' => 'required|max:200',
            'trailer' => 'required|max:255',
            'thumbnail' => 'required',
            'poster' => 'required',
            'duration' => 'required',
            'quality' => 'required',
            'long_description' => 'required',
            'short_description' => 'required',
            'actor' => 'required',
            'director' => 'required',
            'genre' => 'required',
            'category' => 'required',
            'year' => 'required|max:10',
            'rating' => 'required',
            'content_type' => 'required'
        ]);
        if($request->thumbnail){
            $thumbnail = time().'.jpg';
        }else{
            $thumbnail = 0;
        }
        if($request->poster){
            $poster = time().'.jpg';
        }else{
            $poster = 0;
        }
        if($request->source_type == 'local_file'){
            $url = time().'.'.$request->local_file->getClientOriginalExtension();;
            $url_type = 'local_file';
        }elseif($request->source_type == 'youtube_url'){
            $url = $request->youtube_url;
            $url_type = 'youtube_url';
        }elseif($request->source_type == 'drive_url'){
            $url = $request->drive_url;
            $url_type = 'drive_url';
        }
       
        $data = array(
            'title' => $request->title,
            'trailer' => $request->trailer,
            'url' => $url,
            'url_type' => $url_type,
            'thumbnail' => $thumbnail,
            'poster' => $poster,
            'duration' => $request->duration,
            'quality' => $request->quality,
            'long_description' => $request->long_description,
            'short_description' => $request->short_description,
            'actor' => implode('|', $request->actor),
            'director' => $request->director,
            'genre' => $request->genre,
            'category' => $request->category,
            'year' => $request->year,
            'country' => $request->country,
            'rating' => $request->rating,
            'is_trending' => $request->is_trending,
            'featured' => $request->featured,
            'type' => 'movie',
            'content_type' => $request->content_type,
            'created_at' => Carbon::now(),
            'updated_at' => Carbon::now(),
        );
        $insert = Movie::insert($data);
        if($insert){
            if($request->local_file){
                $request->local_file->storeAs('public/movies',$url);
            }
            if($request->poster){
                $request->poster->storeAs('public/movie_poster',$poster);
            }
            if($request->thumbnail){
                $request->thumbnail->storeAs('public/movie_thumbnail',$thumbnail);
            }
            Alert::success(get_phrase('Success'), get_phrase('Movie Created Successfully'));
            return redirect('admin/list/movie');
        }else{
            Alert::error(get_phrase('Retry'), get_phrase('Somthing Wrong'));
            return redirect()->back();
        }
    }

    // movie edit page
    public function edit($id){
        $page_data['movie_details'] = Movie::where('id', $id)->first();
        $page_data['genre'] = Genre::get();
        $page_data['director'] = Director::get();
        $page_data['actor'] = Actor::get();
        $page_data['country'] = Country::get();
        $page_data['category'] = Category::get();
        return view('admin.movie.edit', $page_data);
    }

    // movie update
    public function update(Request $request, $id){
        $validatedData   = $request->validate([
            'title' => 'required|max:200',
            'trailer' => 'required|max:255',
            'duration' => 'required',
            'quality' => 'required',
            'long_description' => 'required',
            'short_description' => 'required',
            'director' => 'required',
            'genre' => 'required',
            'category' => 'required',
            'year' => 'required|max:10',
            'rating' => 'required',
        ]);
        if($request->thumbnail){
            $thumbnail = time().'.jpg';
        }else{
            $thumbnail = $request->old_thumbnail;
        }
        if($request->poster){
            $poster = time().'.jpg';
        }else{
            $poster = $request->old_poster;
        }
        // video source 
        if($request->source_type == 'local_file'){
            if($request->local_file){
                $url = time().'.'.$request->local_file->getClientOriginalExtension();;
                $url_type = 'local_file';
            }else{
                $movie = Movie::where('id', $id)->first();
                $url = $movie->url;
                $url_type = 'local_file';
            }            
        }elseif($request->source_type == 'youtube_url'){
            $url = $request->youtube_url;
            $url_type = 'youtube_url';
        }elseif($request->source_type == 'drive_url'){
            $url = $request->drive_url;
            $url_type = 'drive_url';
        }
        $data = array(
            'title' => $request->title,
            'trailer' => $request->trailer,
            'url' => $url,
            'url_type' => $url_type,
            'thumbnail' => $thumbnail,
            'poster' => $poster,
            'duration' => $request->duration,
            'quality' => $request->quality,
            'long_description' => $request->long_description,
            'short_description' => $request->short_description,
            'actor' => implode('|', $request->actor),
            'director' => $request->director,
            'genre' => $request->genre,
            'category' => $request->category,
            'year' => $request->year,
            'country' => $request->country,
            'rating' => $request->rating,
            'is_trending' => $request->is_trending,
            'featured' => $request->featured,
            'type' => 'movie',
            'content_type' => $request->content_type,
            'updated_at' => Carbon::now(),
        );
      
        if($request->local_file){
            $movie = Movie::where('id', $id)->first();
            unlink('storage/movies/'.$movie->url);
        }
        $update = Movie::where('id', $id)->update($data);
        if($update){
            if($request->local_file){
                $request->local_file->storeAs('public/movies',$url);
            }
            if($request->poster){
                if(file_exists('public/storage/movie_poster/'.$request->old_poster)){
                unlink('public/storage/movie_poster/'.$request->old_poster);
                }
                $request->poster->storeAs('public/movie_poster',$poster);
            }
            if($request->thumbnail){
                if(file_exists('public/storage/movie_thumbnail/'.$request->old_thumbnail)){
                unlink('public/storage/movie_thumbnail/'.$request->old_thumbnail);
                }
                $request->thumbnail->storeAs('public/movie_thumbnail',$thumbnail);
            }
            Alert::success(get_phrase('Success'), get_phrase('Movie Updated Successfully'));
            return redirect()->route('list/movie');
        }else{
            Alert::error(get_phrase('Retry'), get_phrase('Somthing Wrong'));
            return redirect()->back();
        }
    }

    // movie delete
    public function delete($id){
        $movie = Movie::where('id', $id);
        if(file_exists('storage/movie_poster/'.$movie->first()->poster)){
            unlink('storage/movie_poster/'.$movie->first()->poster);
        }
        if(file_exists('storage/movie_thumbnail/'.$movie->first()->thumbnail)){
            unlink('storage/movie_thumbnail/'.$movie->first()->thumbnail);
        }
        if(file_exists('storage/movies/'.$movie->first()->url)){
            unlink('storage/movies/'.$movie->first()->url);
        }
        $delete = $movie->delete();
        if($delete){
            Alert::info(get_phrase('Success'), get_phrase('Movie Deleted Successfully'));
            return redirect()->back();
        }else{
            Alert::error(get_phrase('Retry'), get_phrase('Somthing Wrong'));
            return redirect()->back();
        }
    }

    // trailer preview
    // public function trailer_preview(Request $request){
    //     $page_data['trailer_preview_url'] = $request->trailer;
    //     return view('admin.movie.trailer_preview', $page_data);
    // }


    public function trailer_preview(Request $request){
        $trailer_preview_url = $request->trailer;
        $youtube_trailer_id = $this->extractYoutubeId($trailer_preview_url);
        $page_data['trailer_preview_url'] = $youtube_trailer_id ? "https://www.youtube.com/embed/{$youtube_trailer_id}" : null;
        return view('admin.movie.trailer_preview', $page_data);
    }
    
    private function extractYoutubeId($url) {
        $pattern = '/(?:https?:\/\/)?(?:www\.)?(?:youtube\.com\/(?:[^\/\n\s]+\/\S+\/|(?:v|e(?:mbed)?)\/|\S*?[?&]v=)|youtu\.be\/)([a-zA-Z0-9_-]{11})/i';
        preg_match($pattern, $url, $matches);
        return $matches[1] ?? null;
    }
    

    // url preview
    // public function url_preview(Request $request){
    //     $page_data['url_preview_url'] = $request->url;
    //     $page_data['url_type'] = $request->url_type;
    //     return view('admin.movie.url_preview', $page_data);
    // }


    public function url_preview(Request $request){
        $url = $request->url;
        $url_type = $request->url_type;
    
        if ($url_type == 'youtube_url') {
            $youtube_url_id = $this->extractYoutube($url);
            $page_data['url_preview_url'] = "https://www.youtube.com/embed/{$youtube_url_id}";
        } else if ($url_type == 'drive_url') {
            $drive_video_id = $this->extractDriveId($url);
            $page_data['url_preview_url'] = "https://www.googleapis.com/drive/v3/files/{$drive_video_id}?alt=media&key=" . get_settings('google_api_key');
        }
    
        $page_data['url_type'] = $url_type;
        return view('admin.movie.url_preview', $page_data);
    }
    
    private function extractYoutube($url) {
        $pattern = '/(?:https?:\/\/)?(?:www\.)?(?:youtube\.com\/(?:[^\/\n\s]+\/\S+\/|(?:v|e(?:mbed)?)\/|\S*?[?&]v=)|youtu\.be\/)([a-zA-Z0-9_-]{11})/i';
        preg_match($pattern, $url, $matches);
        return $matches[1] ?? null;
    }
    
    private function extractDriveId($url) {
        $pattern = '/\/file\/d\/(.*?)\/view/i';
        preg_match($pattern, $url, $matches);
        return $matches[1] ?? null;
    }
    
}
