<?php

namespace App\Http\Controllers\Admin\Package;

use App\Http\Controllers\Controller;
use App\Models\Package;
use Carbon\Carbon;
use Illuminate\Http\Request;
use RealRashid\SweetAlert\Facades\Alert;

class PackageController extends Controller{
    // package list page
    public function index(){
        $page_data['packages'] = Package::get();
        return view('admin.package.index', $page_data);
    }

    // create package
    public function create(){
        return view('admin.package.create');
    }

    // store package
    public function store(Request $request){
        $validatedData = $request->validate([
            'name' => 'required|max:20',
            // 'price' => 'required',
            'user_number' => 'required',
            'status' => 'required',
        ]);
    
        $packages = Package::get()->count();
        if($packages >= 3){
            Alert::error(get_phrase('Retry'), get_phrase('Already Three Package Created'));
            return redirect()->back();
        }
        // $data = array(
        //     'name' => $request->name,
        //     'price' => $request->price,
        //     'status' => $request->status,
        //     'user_number' => $request->user_number,
        //     'screen_number' => $request->screen_number,
        //     'services' => json_encode($request->services),
        //     'movie' => json_encode($request->movie),
        //     'end_time' => 1,
        //     'created_at' => Carbon::now(),
        //     'updated_at' => Carbon::now(),
        // );
        $data = [
            'name' => $request->name,
            'status' => $request->status,
            'user_number' => $request->user_number,
            'screen_number' => $request->screen_number,
            'services' => json_encode($request->services),
            'movie' => $request->movie,
            'series' => $request->series,
            'full_access' => $request->full_access,
            'end_time' => 1,
            'created_at' => Carbon::now(),
            'updated_at' => Carbon::now(),
        ];
        if ($request->has('free')) {
            $data['price'] = 'free';
        } else {
            $data['price'] = $request->price;
        }
        $insert = Package::insert($data);
        if($insert){
            Alert::success(get_phrase('Success'), get_phrase('Package Created Successfully'));
            return redirect()->back();
        }else{
            Alert::error(get_phrase('Retry'), get_phrase('Somthing Wrong'));
            return redirect()->back();
        }
    }

    // edit package
    public function edit($id){
        $page_data['package_details'] = Package::where('id', $id)->first();
        return view('admin.package.edit', $page_data);
    }

    // update package
    public function update(Request $request, $id){
        $validatedData = $request->validate([
            'name' => 'required|max:20',
            // 'price' => 'required|max:5',
            'user_number' => 'required',
            'status' => 'required',
        ]);
        $data = array(
            'name' => $request->name,
            // 'price' => $request->price,
            'status' => $request->status,
            'user_number' => $request->user_number,
            'screen_number' => $request->screen_number,
            'movie' => $request->movie,
            'series' => $request->series,
            'full_access' => $request->full_access,
            'services' => json_encode($request->services),
            'updated_at' => Carbon::now(),
        );
        if($request->has('free')) {
            $data['price'] = 'free';
        } else {
            $data['price'] = $request->price;
        }
        $update = Package::where('id', $id)->update($data);
        if($update){
            Alert::success(get_phrase('Success'), get_phrase('Package Updated Successfully'));
            return redirect()->back();
        }else{
            Alert::error(get_phrase('Retry'), get_phrase('Somthing Wrong'));
            return redirect()->back();
        }
    }

    // delete package
    public function delete($id){
        $delete = Package::where('id', $id)->delete();
        if($delete){
            Alert::info(get_phrase('Success'), get_phrase('User Deleted Successfully'));
            return redirect()->back();
        }else{
            Alert::error(get_phrase('Retry'), get_phrase('Somthing Wrong'));
            return redirect()->back();
        }
    }
}
