<?php

namespace App\Http\Controllers\Admin\Setting;

use App\Http\Controllers\Controller;
use App\Models\Faq;
use Carbon\Carbon;
use Illuminate\Http\Request;
use RealRashid\SweetAlert\Facades\Alert;

class FaqController extends Controller{
    // customer faq list page
    public function index(){
        $page_data['faq'] = Faq::paginate(10);
        return view('admin.setting.customer_faq', $page_data);
    }

    // faq create
    public function create(){
        return view('admin.setting.faq_create');
    }

    // faq edit
    public function store(Request $request){
        $validatedData = $request->validate([
            'question' => 'required|max:100',
            'answer' => 'required|max:255',
        ]);
        $data = array(
            'question' => $request->question,
            'answer' => $request->answer,
            'created_at' => Carbon::now(),
            'updated_at' => Carbon::now(),
        );
        $insert = Faq::insert($data);
        if($insert){
            Alert::success(get_phrase('Success'), get_phrase('FAQ Created Successfully'));
            return redirect()->back();
        }else{
            Alert::error(get_phrase('Retry'), get_phrase('Somthing Wrong'));
            return redirect()->back(); 
        }
    }

    // faq edit
    public function edit($id){
        $page_data['question_details'] = Faq::where('id', $id)->first();
        return view('admin.setting.faq_edit', $page_data);
    }

    // faq update
    public function update(Request $request, $id){
        $validatedData = $request->validate([
            'question' => 'required|max:50',
            'answer' => 'required|max:255',
        ]);
        $data = array(
            'question' => $request->question,
            'answer' => $request->answer,
            'updated_at' => Carbon::now(),
        );
        $update = Faq::where('id', $id)->update($data);
        if($update){
            Alert::success(get_phrase('Success'), get_phrase('FAQ Updated Successfully'));
            return redirect()->back();
        }else{
            Alert::error(get_phrase('Retry'), get_phrase('Somthing Wrong'));
            return redirect()->back();
        }
    }

    // faq delete
    public function delete($id){
        $delete = Faq::where('id', $id)->delete();
        if($delete){
            Alert::info(get_phrase('Success'), get_phrase('FAQ Deleted Successfully'));
            return redirect()->back();
        }else{
            Alert::error(get_phrase('Retry'), get_phrase('Somthing Wrong'));
            return redirect()->back();
        }
    }
}
