<?php

namespace App\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use App\Models\User;
use App\Providers\RouteServiceProvider;
use Carbon\Carbon;
use Illuminate\Auth\Events\Registered;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Session;
use Illuminate\Validation\Rules;
use RealRashid\SweetAlert\Facades\Alert;

class RegisteredUserController extends Controller
{
    /**
     * Display the registration view.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('auth.register');
    }

    /**
     * Handle an incoming registration request.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\RedirectResponse
     *
     * @throws \Illuminate\Validation\ValidationException
     */
    public function store(Request $request){
        $validated = $request->validate([
            'name' => 'required',
            'user_name' => 'required',
            'password' => 'required',
            'email' => 'required'
            // 'email' => 'required|unique:users|max:50|email:rfc,dns'
        ]);
        $data = array(
            'name' => $request->name,
            'user_name' => $request->user_name,
            'email' => $request->email,
            'image' => 0,
            'password' => Hash::make($request->password),
            'user_type' => 'user',
            'created_at' => Carbon::now(),
            'updated_at' => Carbon::now(),
        );
        $is_exist = User::where('email', $request->email)->first();
        if($is_exist){
            toast(get_phrase('User already exist'), 'error');
            return redirect()->back();
        }else{

            $insert = User::insert($data);
            if($insert){
                $image_name = 0;
                $request_data = array(
                    'name' => $request->name,
                    'image' => $image_name
                );
                // create default user
                $data = array(
                    'user1' => json_encode($request_data)
                );
                User::where('email', $request->email)->update($data);        
                if(get_settings('email_verification') == 'on'){
                    $code = random_int(100000, 999999);
                    $data['email_verification_code'] = $code;
                    $user = User::where('email', $request->email);
                    $update = $user->update($data);
                    $user_id =$user->first()->id;
                    if($update){
                        send_mail($user_id, 'sign_up', $code);
                        toast(get_phrase('Verification email send successfully'),'success');
                        $user_email['email'] = $request->email;
                        $request->session()->put('email', (object)$user_email);
                        return redirect('user-verification');
                    }else{
                        toast(get_phrase('User not exist'),'error');
                        return redirect()->back();        
                    }
                }else{
                    toast(get_phrase('User Registered Successfully'), 'success');
                    return redirect('login');
                }
            }else{
                toast(get_phrase('Somthing Wrong'),'error');
                return redirect()->back();
            }
                        
        }
    }



    // get password recovery code
    public function user_verification(){
        return view('auth.user_verification');
    }
    // get password recovery code
    public function user_verification_post(Request $request){
        $user_email = Session::get('email')->email;

        $data['is_verified'] = 1;
        $user = User::where('email', $user_email);
        $update = $user->update($data);
        if($user->first()->email_verification_code == $request->v_code){
            if($update){
                toast(get_phrase('Successfully verified'), 'success');
                return redirect('login');
            }else{
                toast(get_phrase('Somthing Wrong'), 'error');
                return redirect()->back();
            }
        }else{
            toast(get_phrase('Invalid verification code'), 'error');
            return redirect()->back();
        }
    }









}
