<?php

use App\Http\Controllers\Auth\AuthenticatedSessionController;
use App\Http\Controllers\Auth\ConfirmablePasswordController;
use App\Http\Controllers\Auth\EmailVerificationNotificationController;
use App\Http\Controllers\Auth\EmailVerificationPromptController;
use App\Http\Controllers\Auth\NewPasswordController;
use App\Http\Controllers\Auth\PasswordResetLinkController;
use App\Http\Controllers\Auth\RegisteredUserController;
use App\Http\Controllers\Auth\VerifyEmailController;
use Illuminate\Support\Facades\Route;

Route::middleware('guest')->group(function () {
    Route::get('register', [RegisteredUserController::class, 'create'])
                ->name('register');

    Route::post('register', [RegisteredUserController::class, 'store']);

    Route::get('login', [AuthenticatedSessionController::class, 'index'])
                ->name('login');

    Route::post('login', [AuthenticatedSessionController::class, 'login']);

    // pages 
    Route::get('/forgot-password', [PasswordResetLinkController::class, 'forgot_password'])->name('forgot-password'); // forgot password page view

    Route::post('/forgot-password', [PasswordResetLinkController::class, 'get_code'])->name('get-code'); // get password recovery code 

    Route::get('/confirm-password-code', [PasswordResetLinkController::class, 'confirm_password_view'])->name('confirm-password-code'); // confirm password page view

    Route::get('/user-verification', [RegisteredUserController::class, 'user_verification'])->name('user-verification'); // confirm password page view
    Route::post('/user-verification-post', [RegisteredUserController::class, 'user_verification_post'])->name('user-verification-post'); // confirm password page view

    Route::post('/confirm-password', [PasswordResetLinkController::class, 'confirm_password'])->name('confirm-password'); // get password recovery code 

    // Route::get('forgot-password', [PasswordResetLinkController::class, 'create'])
                // ->name('password.request');

    // Route::post('forgot-password', [PasswordResetLinkController::class, 'store'])
    //             ->name('password.email');

    // Route::get('reset-password', [NewPasswordController::class, 'create'])
    //             ->name('password.reset');

    // Route::post('reset-password', [NewPasswordController::class, 'store'])
    //             ->name('password.update');
});

Route::middleware('auth')->group(function () {
    Route::get('verify-email', [EmailVerificationPromptController::class, '__invoke'])
                ->name('verification.notice');

    Route::get('verify-email/{id}/{hash}', [VerifyEmailController::class, '__invoke'])
                ->middleware(['signed', 'throttle:6,1'])
                ->name('verification.verify');

    Route::post('email/verification-notification', [EmailVerificationNotificationController::class, 'store'])
                ->middleware('throttle:6,1')
                ->name('verification.send');

    Route::post('logout', [AuthenticatedSessionController::class, 'destroy'])
                ->name('logout');
});
