<?php

use App\Http\Controllers\Frontend\FrontendController;
use App\Http\Controllers\Frontend\HomepageController;
use App\Http\Controllers\Frontend\UserProfileController;
use App\Http\Controllers\InstallController;
use Illuminate\Support\Facades\Artisan;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\Updater;
/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

Route::get('/', [HomepageController::class, 'index']); // website home page
Route::get('/home', [HomepageController::class, 'index'])->name('home'); // main homepage

Route::get('/test', function () {
    return view('test');
});

require __DIR__.'/auth.php';

Route::get('/packages', [HomepageController::class, 'packages'])->name('packages'); // packages
// user routes
Route::group(['prefix' => 'user',  'middleware' => 'user'], function(){

    Route::get('/who-is-watching', [UserProfileController::class, 'who_is_watching'])->name('who-is-watching'); // who is watching


});

// user routes
Route::group(['prefix' => 'user','middleware' => 'user'], function(){

    Route::get('/wishlist', [FrontendController::class, 'wishlist'])->name('wishlist'); // packages
    
});

Route::get('/add-wishlist/{video_id}/{type}', [FrontendController::class, 'add_wishlist'])->name('add-wishlist'); // add video to your wishlist
Route::get('/delete/wishlist/{video_id}', [FrontendController::class, 'delete_wishlist'])->name('delete/wishlist'); // add video to your wishlist
Route::get('/invoice/{id}', [HomepageController::class, 'invoice'])->name('invoice'); // faq page 
Route::get('/subscription-cancel', [HomepageController::class, 'subscription_cancel'])->name('subscription-cancel'); // user subscription cancel 

Route::get('/watch-now/{id}/{type}', [FrontendController::class, 'watch_now'])->name('watch-now'); // who is watching
Route::get('/search/{id}/{type}/{name}', [HomepageController::class, 'search'])->name('search'); // header search
Route::get('/filter', [HomepageController::class, 'sidebar_filter'])->name('filter'); // header search


Route::get('/faq', [HomepageController::class, 'faq'])->name('faq'); // faq page 
Route::get('/privacy-policy', [HomepageController::class, 'privacy_policy'])->name('privacy-policy'); // faq page 
Route::get('/refund-policy', [HomepageController::class, 'refund_policy'])->name('refund-policy'); // faq page 

Route::post('/series-view', [FrontendController::class, 'series_view'])->name('series-view'); // series view acoding to episode
Route::get('/episode-player/{episode_id}/{season_id}', [FrontendController::class, 'episode_player'])->name('episode-player'); // episode play page

Route::get('/video-player/{video_id}/{type}', [FrontendController::class, 'video_player'])->name('video-player'); // all video play page
 
Route::any('/newslater', [FrontendController::class, 'newslater'])->name('newslater'); // subscribe to the website

Route::get('/language-chnage/{language}', [FrontendController::class, 'language_chnage'])->name('language-chnage');
Route::get('/cancel-membership', [UserProfileController::class, 'cancel_membership'])->name('cancel-membership');


Route::post('themes-color', [HomepageController::class, 'theme_color'])->name('themes-color');

// User Ban Frontend
Route::post('user/remove/ban/{id}', [HomepageController::class, 'UserBanRequest'])->name('user.remove.ban');


Route::get('/clear-cache', function () {
    Artisan::call('cache:clear');
    Artisan::call('config:clear');
    Artisan::call('route:clear');
    Artisan::call('view:clear');

    return 'Application cache cleared';
});

Route::get('/storage-link', function () {
    Artisan::call('storage:link');
    return 'storage linked successfully';
});


//Updater routes are here
 Route::post('admin/product/update', [Updater::class, 'update'])->name('admin.product.update');
//End Updater routes

//Installation routes
Route::controller(InstallController::class)->group(function () {

    Route::get('/', 'index');
    Route::get('install/step0', 'step0')->name('step0');
    Route::get('install/step1', 'step1')->name('step1');
    Route::get('install/step2', 'step2')->name('step2');
    Route::any('install/step3', 'step3')->name('step3');
    Route::get('install/step4', 'step4')->name('step4');
    Route::get('install/step4/{confirm_import}', 'confirmImport')->name('step4.confirm_import');
    Route::get('install/install', 'confirmInstall')->name('confirm_install');
    Route::post('install/validate', 'validatePurchaseCode')->name('install.validate');
    Route::any('install/finalizing_setup', 'finalizingSetup')->name('finalizing_setup');
    Route::get('install/success', 'success')->name('success');

});
//Installation routes

