<?php

namespace App\Http\Controllers\Admin\Series;

use App\Http\Controllers\Controller;
use App\Models\Episode;
use App\Models\Season;
use App\Models\Series;
use Carbon\Carbon;
use Illuminate\Http\Request;
use RealRashid\SweetAlert\Facades\Alert;

class SeasonController extends Controller{
    // create seasons with ajaxx
    public function create($id){
        $page_data['series'] = Series::where('id', $id)->first();
        $count =Season::where('series', $id)->count();
        if($count){
            $sesson_number = $count + 1;
        }else{
            $sesson_number = 1;
        }
        $page_data['sesson_number'] = $sesson_number;
        return view('admin.series.create_season', $page_data);
    }

    // season store
    public function store_season(Request $request, $id){
        $validatedData = $request->validate([
            'name' => 'required',
            'series' => 'required',
        ]);
        $data = array (
            'season' => $request->name,
            'series' => $id,
            'created_at' => Carbon::now(),
            'updated_at' => Carbon::now(),
        );
        $insert = Season::insert($data);
        if($insert){
            Alert::success(get_phrase('Success'), get_phrase('Season Created Successfully'));
            return redirect()->back();
        }else{
            Alert::error(get_phrase('Retry'), get_phrase('Somthing Wrong'));
            return redirect()->back();
        }
        return redirect()->back();
    }

    // edit season
    public function edit($id){
        $page_data['season_id'] = $id;
        $page_data['episode'] = Episode::where('season', $id)->paginate(10);
        return view('admin.series.edit_season', $page_data);
    }

    // delete season
    public function delete($id){
        Season::where('id', $id)->delete();
        return redirect()->back();
    }

    // create episode
    public function store_episode(Request $request){
        $validatedData = $request->validate([
            'title' => 'required|max:200',
            'season_id' => 'required',
            'duration' => 'required',
            'quality' => 'required',
            'description' => 'required',
            'thumbnail' => 'required',
        ]);
        if($request->thumbnail){
            $thumbnail = time().'.jpg';
        }else{
            $thumbnail = 0;
        }

        if($request->source_type == 'local_file'){
            $url = time().'.'.$request->local_file->getClientOriginalExtension();;
            $url_type = 'local_file';
        }elseif($request->source_type == 'youtube_url'){
            $url = $request->youtube_url;
            $url_type = 'youtube_url';
        }elseif($request->source_type == 'drive_url'){
            $url = $request->drive_url;
            $url_type = 'drive_url';
        }

        $data = array(
            'title' => $request->title,
            'season' => $request->season_id,
            'url' => $url,
            'type' => 'episode',
            'url_type' => $url_type,
            'thumbnail' => $thumbnail,
            'description' => $request->description,
            'quality' => $request->quality,
            'duration' => $request->duration,
            'created_at' => Carbon::now(),
            'updated_at' => Carbon::now()
        );
        $insert = Episode::insert($data);
        if($insert){
            if($request->local_file){
                $request->local_file->storeAs('public/episode',$url);
                // if(file_exists('public/storage/episode')){
                //     unlink('public/storage/series_poster',$request->old_thumbnail);
                // }
            }
            if($request->thumbnail){
                $request->thumbnail->storeAs('public/episode_thumbnail',$thumbnail);
            }
            Alert::success(get_phrase('Success'), get_phrase('Episode Created Successfully'));
            return redirect()->back();
        }else{
            Alert::error(get_phrase('Retry'), get_phrase('Somthing Wrong'));
            return redirect()->back();
        }
    }

    // edit episode
    public function edit_episode($id){
        $page_data['episode_details'] = Episode::where('id', $id)->first();
        return view('admin.series.update_episode', $page_data);
    }

    // episode update
    public function update_episode(Request $request, $id){
        $validatedData = $request->validate([
            'title' => 'required|max:200',
            'description' => 'required',
            'quality' => 'required',
        ]);
        if($request->thumbnail){
            $thumbnail = time().'.jpg';
        }else{
            $thumbnail = $request->old_thumbnail;
        }


        if($request->source_type_edit == 'local_file_edit'){
            if($request->local_file){
                $url = time().'.'.$request->local_file->getClientOriginalExtension();;
                $url_type = 'local_file';
            }else{
                $series = Episode::where('id', $id)->first();
                $url = $series->url;
                $url_type = 'local_file';
            }   
        }elseif($request->source_type_edit == 'youtube_url_edit'){
            $url = $request->youtube_url;
            $url_type = 'youtube_url';
        }elseif($request->source_type_edit == 'drive_url_edit'){
            $url = $request->drive_url;
            $url_type = 'drive_url';
        }
        $data = array(
            'title' => $request->title,
            'url' => $url,
            'type' => 'episode',
            'url_type' => $url_type,
            'duration' => $request->duration,
            'quality' => $request->quality,
            'thumbnail' => $thumbnail,
            'description' => $request->description,
            'updated_at' => Carbon::now()
        );
        if($request->local_file){
            $episode = Episode::where('id', $id)->first();
            if(file_exists('public/storage/episode/'.$episode->url)){
                unlink('public/storage/episode/'.$episode->url);
            }
        }
        $update = Episode::where('id', $id)->update($data);
        if($update){
            if($request->local_file){
                $request->local_file->storeAs('public/episode',$url);
            }
            if($request->thumbnail){
                if(file_exists('public/storage/episode_thumbnail/'.$request->old_thumbnail)){
                    unlink('public/storage/episode_thumbnail/'.$request->old_thumbnail);
                    $request->thumbnail->storeAs('public/episode_thumbnail',$thumbnail);
                }
            }
            Alert::success(get_phrase('Success'), get_phrase('Episode Updated Successfully'));
            return redirect()->back();
        }else{
            Alert::error(get_phrase('Retry'), get_phrase('Somthing Wrong'));
            return redirect()->back();
        }
    }

    // view episode
    public function view_episode($episode_id){
        $page_data['episode'] = Episode::where('id', $episode_id)->first();
        return view('admin.series.view', $page_data);
    }

    // delete episode
    public function delete_episode($id){
        $episode = Episode::where('id', $id)->first();
        if(file_exists('public/storage/episode/'.$episode->thumbnail)){
            unlink('public/storage/episode_thumbnail/'.$episode->thumbnail);
        }
        if(file_exists('public/storage/episode/'.$episode->url)){
            unlink('public/storage/episode/'.$episode->url);
        }
        $delete = Episode::where('id', $id)->delete();
        if($delete){
            Alert::info(get_phrase('Success'), get_phrase('Episode Deleted Successfully'));
            return redirect()->back();
        }else{
            Alert::error(get_phrase('Retry'), get_phrase('Somthing wrong'));
            return redirect()->back();
        }
    }

}
