<?php

namespace App\Http\Controllers\Admin\Series;

use App\Http\Controllers\Controller;
use App\Models\Actor;
use App\Models\Category;
use App\Models\Director;
use App\Models\Genre;
use App\Models\Season;
use App\Models\Series;
use Carbon\Carbon;
use Illuminate\Http\Request;
use RealRashid\SweetAlert\Facades\Alert;

class SeriesController extends Controller{
    // series list page
    public function index(){
        $page_data['series'] = Series::paginate(10);
        return view('admin.series.index', $page_data);
    }

    // series create page
    public function create(){
        $page_data['genre'] = Genre::get();
        $page_data['category'] = Category::get();
        $page_data['director'] = Director::get();
        $page_data['actor'] = Actor::get();
        return view('admin.series.create', $page_data);
    }

    // series store
    public function store(Request $request){
        $validated = $request->all([
            'title' => 'required|max:200',
            'trailer' => 'required|max:255',
            'thumbnail' => 'required',
            'poster' => 'required',
            'long_description' => 'required|255',
            'short_description' => 'required|max:100',
            'actor' => 'required',
            'quality' => 'required',
            'director' => 'required',
            'genre' => 'required',
            'category' => 'required',
            'year' => 'required|max:10',
            'rating' => 'required',
            'content_type' => 'required',
        ]);
        if($request->thumbnail){
            $thumbnail = time().'.jpg';
            $path = $request->thumbnail->storeAs('public/series_thumbnail',$thumbnail);
        }else{
            $thumbnail = 0;
        }
        if($request->poster){
            $poster = time().'.jpg';
            $path = $request->poster->storeAs('public/series_poster',$poster);
        }else{
            $poster = 0;
        }
        $data = array(
            'title' => $request->title,
            'trailer' => $request->trailer,
            'thumbnail' => $thumbnail,
            'poster' => $poster,
            'quality' => $request->quality,
            'long_description' => $request->long_description,
            'short_description' => $request->short_description,
            'actor' => implode('|', $request->actor),
            'director' => $request->director,
            'genre' => $request->genre,
            'category' => $request->category,
            'year' => $request->year,
            'popular_shows' => $request->popular_shows,
            'rating' => $request->rating,
            'type' => 'series',
            'content_type' => $request->content_type,
            'created_at' => Carbon::now(),
            'updated_at' => Carbon::now(),
        );
        $insert = Series::insert($data);
        if($insert){
            Alert::success(get_phrase('Success'), get_phrase('Series Created Successfully'));
            return redirect('admin/list/movie');
        }else{
            Alert::error(get_phrase('Retry'), get_phrase('Somthing Wrong'));
            return redirect()->back();
        }
    }

    // series edit page
    public function edit($id){
        $page_data['series_details'] = Series::where('id', $id)->first();
        $page_data['genre'] = Genre::get();
        $page_data['category'] = Category::get();
        $page_data['director'] = Director::get();
        $page_data['actor'] = Actor::get();
        $page_data['season'] = Season::where('series', $id)->get();
        return view('admin.series.edit', $page_data);
    }

    // series update 
    public function update(Request $request, $id){
        $validated = $request->all([
            'title' => 'required|max:200',
            'trailer' => 'required|max:255',
            'thumbnail' => 'required',
            'poster' => 'required',
            'long_description' => 'required|255',
            'short_description' => 'required|max:100',
            'actor' => 'required',
            'director' => 'required',
            'genre' => 'required',
            'category' => 'required',
            'year' => 'required|max:10',
            'rating' => 'required',
        ]);
        if($request->thumbnail){
            $thumbnail = time().'.jpg';
            $path = $request->thumbnail->storeAs('public/series_thumbnail',$thumbnail);
            if(file_exists('public/storage/series_thumbnail/'.$request->old_thumbnail)){
                unlink('public/storage/series_thumbnail/'.$request->old_thumbnail);
            }
        }else{
            $thumbnail = $request->old_thumbnail;
        }
        if($request->poster){
            $poster = time().'.jpg';
            if(file_exists('public/storage/series_poster/'.$request->old_poster)){
                unlink('public/storage/series_poster/'.$request->old_poster);
            }
            $path = $request->poster->storeAs('public/series_poster',$poster);
        }else{
            $poster = $request->old_poster;
        }
        $data = array(
            'title' => $request->title, 
            'trailer' => $request->trailer,
            'thumbnail' => $thumbnail,
            'poster' => $poster,
            'quality' => $request->quality,
            'long_description' => $request->long_description,
            'short_description' => $request->short_description,
            'actor' => implode('|', $request->actor),
            'director' => $request->director,
            'genre' => $request->genre,
            'category' => $request->category,
            'year' => $request->year,
            'popular_shows' => $request->popular_shows,
            'rating' => $request->rating,
            'type' => 'series',
            'content_type' => $request->content_type,
            'updated_at' => Carbon::now(),
        );
   
        $update = Series::where('id', $id)->update($data);
        if($update){
            
            Alert::success(get_phrase('Success'), get_phrase('Series Updated Successfully'));
            return redirect('admin/list/series');
        }else{
            Alert::error(get_phrase('Retry'), get_phrase('Somthing Wrong'));
            return redirect()->back();
        }
    }

    // series delete
    public function delete($id){
        $old = Series::where('id', $id)->first();
        $delete = Series::where('id', $id)->delete();
        if($delete){
            if(file_exists('public/storage/series_thumbnail/'.$old->thumbnail)){
                unlink('public/storage/series_thumbnail/'.$old->thumbnail);
            }
            if(file_exists('public/storage/series_poster/'.$old->poster)){
                unlink('public/storage/series_poster/'.$old->poster);
            }
            Alert::info(get_phrase('Success'), get_phrase('Series Deleted Successfully'));
            return redirect()->back();
        }else{
            Alert::error(get_phrase('Retry'), get_phrase('Somthing wrong'));
            return redirect()->back();
        }
    }
 
    // // trailer preview
    // public function trailer_preview(Request $request){
    //     $page_data['trailer_preview_url'] = $request->url;
    //     $page_data['url_type'] = $request->url_type;
    //     return view('admin.series.trailer_preview', $page_data);
    // }
    public function trailer_preview(Request $request){
        $url = $request->url;
        $url_type = $request->url_type;
    
        if ($url_type == 'youtube_url') {
            $youtube_url_id = $this->extractYoutubeId($url);
            $page_data['trailer_preview_url'] = "https://www.youtube.com/embed/{$youtube_url_id}";
        } else if ($url_type == 'drive_url') {
            $drive_video_id = $this->extractDriveId($url);
            $page_data['trailer_preview_url'] = "https://www.googleapis.com/drive/v3/files/{$drive_video_id}?alt=media&key=" . get_settings('google_api_key');
        }
    
        $page_data['url_type'] = $url_type;
        return view('admin.series.trailer_preview', $page_data);
    }
    
    private function extractYoutubeId($url) {
        $pattern = '/(?:https?:\/\/)?(?:www\.)?(?:youtube\.com\/(?:[^\/\n\s]+\/\S+\/|(?:v|e(?:mbed)?)\/|\S*?[?&]v=)|youtu\.be\/)([a-zA-Z0-9_-]{11})/i';
        preg_match($pattern, $url, $matches);
        return $matches[1] ?? null;
    }
    
    private function extractDriveId($url) {
        $pattern = '/\/file\/d\/(.*?)\/view/i';
        preg_match($pattern, $url, $matches);
        return $matches[1] ?? null;
    }
    
    

}
 