<?php

namespace App\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use App\Http\Requests\Auth\LoginRequest;
use App\Models\Package;
use App\Models\User;
use Illuminate\Support\Facades\Hash;
use App\Providers\RouteServiceProvider;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Session;
use RealRashid\SweetAlert\Facades\Alert;

class AuthenticatedSessionController extends Controller
{
    /**
     * Display the login view.
     *
     * @return \Illuminate\View\View
     */
    public function index(Request $request){
        $check_admin = Session::get('admin');
        $check_user = Session::get('user');
        if($check_admin){
            return redirect('admin/dashboard');
        }elseif($check_user){
            return redirect('home');
        }

        $test['login_ip'] = $request->header('referer');

        return view('auth.login', $test);
    }

    /**
     * Handle an incoming authentication request.
     *
     * @param  \App\Http\Requests\Auth\LoginRequest  $request
     * @return \Illuminate\Http\RedirectResponse
     */
    public function login(Request $request){

        $validated = $request->validate([
            'email' => 'required',
            // 'email' => 'required|max:50|email:rfc,dns',
            'password' => 'required',
        ]);
        $email = $request->email;
        $password = $request->password;
        $is_admin = User::where('email', $email)->first();
        if($is_admin && $is_admin->user_type == 'admin'){
            if(Hash::check($password, $is_admin->password) && $email == $is_admin->email){
                $data = array(
                    'id' => $is_admin->id,
                    'email' => $email,
                    'user_type' => $is_admin->user_type,
                    'name' => $is_admin->name,
                );
                $request->session()->put('admin', (object)$data);
                Alert::success(get_phrase('Welcome!'), get_phrase('Login Successfully'));
                return redirect('admin/dashboard');
            }else{
                toast(get_phrase('Credential Not Match'),'error');
                return redirect()->back();
            }
        }elseif($is_admin && $is_admin->user_type == 'user'){
            if(Hash::check($password, $is_admin->password) && $email == $is_admin->email){
                if($is_admin->is_verified == 0 && get_settings('email_verification') == 'on'){
                    $code = random_int(100000, 999999);
                    $data['email_verification_code'] = $code;
                    $user = User::where('email', $email);
                    $update = $user->update($data);
                    $user_id =$user->first()->id;
                    if($update){
                        send_mail($user_id, 'sign_up', $code);
                        toast(get_phrase('Verification email send successfully'),'success');
                        $user_email['email'] = $email;
                        $request->session()->put('email', (object)$user_email);
                        return redirect('user-verification');
                    }else{
                        toast(get_phrase('Verification email not send !'),'error');
                        return redirect()->back();        
                    }
                }else{
                    $user = User::where('email', $email);
                    if(strtotime($is_admin->updated_at)+10800 < time()){
                        $device['login_device'] = $user->first()->login_device - 1;
                        $user->update($device);
                    }
                    $package = Package::where('id', $is_admin->plan)->first();
                    if($package->screen_number??1 > $user->first()->login_device){
                        $device['login_device'] = $user->first()->login_device + 1;
                        $device['updated_at'] = Carbon::now();
                        $login_device = $user->update($device);

                        if($login_device){
                            $data = array(
                                'id' => $is_admin->id,
                                'email' => $email,
                                'user_type' => $is_admin->user_type,
                                'name' => $is_admin->name,
                            );
                            $request->session()->put('user', (object)$data);
                            if(premium_user($is_admin->id) == 1){
                                toast(get_phrase('Login Successfully'),'success');
                                return redirect('user/who-is-watching');
                            }else{
                                toast(get_phrase('Login Successfully'),'success');
                                return redirect('home');
                            }
                        }else{
                            toast(get_phrase('Somthing Wrong'),'error');
                            return redirect()->back();
                        }
                    }else{
                        toast(get_phrase('Login Device Limit Reached'),'error');
                        return redirect()->back();
                    }
                }                
            }else{
                toast(get_phrase('Wrong Password'),'error');
                return redirect()->back();
            }
        }else{
            toast(get_phrase('User Not found !'),'error');
            return redirect()->back();
        }
        
    }

    /**
     * Destroy an authenticated session.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\RedirectResponse
     */
    public function destroy(Request $request){
        Session::flush('admin');
        return redirect('/');
    }
}
