<?php

namespace App\Http\Controllers\Payment;

use App\Http\Controllers\Controller;
use App\Models\Currency;
use App\Models\User;
use App\Models\Package;
use App\Models\Payment;
use App\Models\payment_gateway\Stripe;
use App\Models\Paypal;
use App\Models\payment_gateway\Razorpay;
use App\Models\Payment_geteway;
use App\Models\Subscription;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Session;
use RealRashid\SweetAlert\Facades\Alert;

use Razorpay\Api\Api;
use Illuminate\Support\Str;

use Carbon\Carbon;

class PaymentController extends Controller{
 
    public function index(Request $request, $id){
        $package = Package::where('id', $id)->first();
        $desiredTimeZone = get_settings('timezone');
        date_default_timezone_set($desiredTimeZone);
        $payment_details = [
            'items' =>[
                [
                    'id' => $package->id,
                    'title' => $package->name,
                    'subtitle' => 0,
                    'price' => $package->price,
                    'discount_price' => 0,
                    'discount_percentage' => 0
                ]
            ],
            'custom_field' => [
                'start_date' => date('Y-m-d H:i:s', time()),
                'end_date' => date('Y-m-d H:i:s', strtotime("+1 month", time())),
            ],
            'success_method' => [
                'model_name' => 'Payment_geteway',
                'function_name' => 'add_payment_success'
            ],
            'tax' => 0,
            'coupon' => null,
            'payable_amount' => $package->price,
            'cancel_url' => route('packages'),
            'success_url' => route('payment.success', ''),
        ];

        $request->session()->put('payment_details', $payment_details);
    
        $payment_details = Session::get('payment_details');
        if(!$payment_details || !is_array($payment_details) || count($payment_details) <= 0){
            Alert::error(get_phrase('Retry'), get_phrase('Payment not configured yet'));
            return redirect()->back();
        }
        if($payment_details['payable_amount'] <= 0){
            Alert::error(get_phrase('Retry'), get_phrase('Payable amount cannot be less than 1'));
            return redirect()->to($payment_details['cancel_url']);
        }

        $page_data['payment_details'] = $payment_details;
        $page_data['payment_gateways'] = Payment_geteway::where('status', 1)->get();
        return view('payment.index', $page_data);
    }

    function payment_success($identifier, Request $request){
        $payment_details = session('payment_details');
        $payment_gateway = Payment_geteway::where('identifier', $identifier)->first();
        $model_name = $payment_gateway->model_name;
        $model_full_path = str_replace(' ', '', 'App\Models\payment_gateway\ '.$model_name);

        $status = $model_full_path::payment_status($identifier, $request->all());

        if($status === true){
            $success_model = $payment_details['success_method']['model_name'];
            $success_function = $payment_details['success_method']['function_name'];    

            $model_full_path = str_replace(' ', '', 'App\Models\ '.$success_model);
            return $model_full_path::$success_function($identifier, $payment_gateway->currency);
        }else{
            // flash()->addError(get_phrase('Payment failed! Please try again.'));
            Alert::error(get_phrase('Retry'), get_phrase('Payment failed! Please try again.'));
            redirect()->to($payment_details['cancel_url']);
        }
    }

        
    public function payment_settings(){
        $page_data['payment_gateways'] = Payment_geteway::get();
        // $page_data['view_path'] = 'payment.payment_gateways';
        return view('payment.payment_gateways', $page_data);
    }

    public function payment_gateway_edit($id){
        $page_data['payment_gateway'] = Payment_geteway::where('id', $id)->first();
        // $page_data['view_path'] = 'payment.payment_gateway_edit';
        $page_data['currency'] = Currency::get();
        return view('payment.payment_gateway_edit', $page_data);
    }

    public function payment_gateway_status($id){
        $query = Payment_geteway::where('id', $id);
        if($query->value('status') == 1){
            $query->update(['status' => 0]);
        }else{
            $query->update(['status' => 1]);
        }
        Alert::success(get_phrase('Success'), get_phrase('Payment gateway status changed successfully'));
        return redirect()->back();
    }

    function payment_gateway_update($id, Request $request){
        $keys = array();
        $all_data = $request->all();        
        unset($all_data['_token']);
        $data['keys'] = json_encode($all_data);
        $currency['currency'] = $request->currency;
        Payment_geteway::select('currency')->where('id', $id)->update($currency);
        Payment_geteway::find($id)->update($data);
        Alert::success(get_phrase('Success'), get_phrase('Payment gateway has been updated'));
        return redirect('admin/payment');
    }

    function payment_gateway_environment($id){
        $query = Payment_geteway::where('id', $id);
        if($query->value('test_mode') == 1){
            $query->update(['test_mode' => 0]);
        }else{
            $query->update(['test_mode' => 1]);
        }
        Alert::success(get_phrase('Success'), get_phrase('Payment gateway environment changed successfully'));
        return redirect()->back();
    }

    function show_payment_gateway_by_ajax($identifier){
        $page_data['payment_details'] = session('payment_details');
        $page_data['payment_gateway'] = Payment_geteway::where('identifier', $identifier)->first();
        return view('payment.'.$identifier.'.index', $page_data);
    }

    function payment_create($identifier){
        $payment_details = Session::get('payment_details');
        $payment_gateway = Payment_geteway::where('identifier', $identifier)->first();
        $model_name = $payment_gateway->model_name;
        $model_full_path = str_replace(' ', '', 'App\Models\payment_gateway\ '.$model_name);
        $created_payment_link= $model_full_path::payment_create($identifier);
        return redirect()->to($created_payment_link);
         
    }


    // Razorpay Payment
    public function payment_razorpay($identifier)
    {
        $payment_details = session('payment_details');
        $payment_gateway = DB::table('payment_geteways')->where('identifier', $identifier)->first();
        $model_name = $payment_gateway->model_name;
        $model_full_path = str_replace(' ', '', 'App\Models\payment_gateway\\' . $model_name);
    
        $data = $model_full_path::payment_create($identifier);
    
        return view('payment.razorpay.payment', compact('data'));
    }


    // subscription_history
    public function subscription_history(){
        $page_data['subscription_history'] = Subscription::orderBy('id','DESC')->paginate(10);
        return view('payment.subscription_history',$page_data);
    }


    // User Free Payment
    public function free_payment(Request $request , $id){
        $package = Package::where('id', $id)->first();
        $subscriptions = Subscription::where('plan_id', $id)->where('user_id', get_user('id'))->first();
        if($package->price == 'free' && isset($subscriptions) && $subscriptions->id){
            Alert::error(get_phrase('Retry'), get_phrase('You Allready Purchase Free Plan'));
            return redirect()->back();
        }

        $data = array(
            'plan_id' => $id,
            'user_id' => get_user('id'),
            'price_amount' => 0,
            'paid_amount' => 0,
            'timestamp_from' => date('Y-m-d H:i:s', time()),
            'timestamp_to' => date('Y-m-d H:i:s', strtotime("+1 month", time())),
            'payment_method' => 'free',
            'payment_details' => 'free',
            'payment_timestamp' => date('Y-m-d H:i:s', time()),
            'status' => 1,
            'currency' => get_settings('currency'),
            'created_at' => Carbon::now(),
            'updated_at' => Carbon::now(),
        );
        $insert = Subscription::insert($data);
        if($insert){
            $package_info = Package::where('id', $id)->firstOrFail();
            $list = User::where('id',get_user('id'))->first();
            $movie = json_decode($list->subscription_list)->movie??0;
            $series = json_decode($list->subscription_list)->series??0;
            
            $subscription_list = [
                'movie' =>(isset($movie) > 0) ? $package_info->movie + $movie : $movie,
                'series' =>(isset($series) > 0) ? $package_info->series + $series : $series,
            ];
            $subscription_list_json = json_encode($subscription_list);
            $plan = array(
                'plan' => $id,
                'subscription_list' => $subscription_list_json
            );
            DB::table('users')->where('id', get_user('id'))->update($plan);
            Alert::success(get_phrase('Success'), get_phrase('Subscription Created Successfully'));
            return redirect()->route('user/active-package');
        }else{
            Alert::error(get_phrase('Retry'), get_phrase('Somthing Wrong'));
            return redirect()->back();
        }
    }


    
}
