<?php

// Important Functions

// phrase language

use App\Models\Currency;
use App\Models\Episode;
use App\Models\Movie;
use App\Models\Package;
use App\Models\Season;
use App\Models\Series;
use App\Models\Subscription;
use App\Models\User;
use Carbon\Carbon;
use Illuminate\Support\Facades\Config;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Mail;

if ( ! function_exists('get_all_language'))
{
    function get_all_language(){
        return DB::table('languages')->select('name')->distinct()->get();
    }
}

if(!function_exists('get_language')){
    function get_language(){
        $session_language = Session::get('language');
        if(!$session_language){
            $language = get_settings('language');
            Session::put('language', ['language'=>$language, 'setting'=>'0']);
            $session_language = Session::get('language');
        }
        // print_r($session_language);
        // die;
        return $session_language['language'];
    }
}

// language phrase
if ( ! function_exists('get_phrase'))
{
    function get_phrase($phrase = '', $value_replace = array()) {
        $session_language = Session::get('language');

        if(isset($session_language['language'])){
            $active_language = $session_language['language'];
        }else{
            $active_language = get_settings('language');
        }
        $query = DB::table('languages')->where('name', $active_language)->where('phrase', $phrase);
        if($query->count() > 0){
            $tValue = $query->value('translated');
        }else{
            $tValue = $phrase;
            $all_language = get_all_language();
            
            if($all_language->count() > 0){
                foreach($all_language as $language){
                    
                    if(DB::table('languages')->where('name', $language->name)->where('phrase', $phrase)->get()->count() == 0){
                        DB::table('languages')->insert(array('name' => strtolower($language->name), 'phrase' => $phrase, 'translated' => $phrase));
                    }
                }
            }else{
                DB::table('languages')->insert(array('name' => 'english', 'phrase' => $phrase, 'translated' => $phrase));
            }
        }
        return $tValue;
    }
}

// get image with placeholder
if(!function_exists('get_image')){
    function get_image($url){
        
        if($_SERVER['SERVER_NAME'] == 'localhost' || $_SERVER['SERVER_NAME'] == '127.0.0.1') {
            if(file_exists('public/'.$url)){
                return asset($url);
            }
            else{
                return asset('storage/image/placeholder.jpg');
            }
        }else{
            if(file_exists('public/'.$url)){
               
                return asset($url);
            }
            else{
                return asset('storage/image/placeholder.jpg');
            }
        }
    }
}

// get user sesson
if(!function_exists('get_user')){
    function get_user($data){
        $admin = Session::get('admin');
        $user = Session::get('user');
        if($admin){
            $admin = User::where('email', $admin->email)->first();
            return $admin->$data;
        }elseif($user){
            if(isset($user->$data)){
                return $user->$data;
            }else{
                return "";
            }
        }
    }
}

// get user number
if(!function_exists('get_user_number')){
    function get_user_number($data){
        if($data == 1){
            echo get_phrase('One User');
        }elseif($data == 2){
            echo get_phrase('Two Users');
        }elseif($data == 3){
            echo get_phrase('Three Users');
        }elseif($data == 4){
            echo get_phrase('Four Users');
        }
    }
}
// get user screen
if(!function_exists('get_screen')){
    function get_screen($data){
        if($data == 2){
            echo get_phrase('Two Screens');
        }elseif($data == 4){
            echo get_phrase('Four Screens');
        }elseif($data == 6){
            echo get_phrase('Six Screens');
        }
    }
}

if (!function_exists('ellipsis')) {
    function ellipsis($long_string, $max_character = 30)
    {
        $long_string = strip_tags($long_string);
        $short_string = strlen($long_string) > $max_character ? mb_substr($long_string, 0, $max_character) . "..." : $long_string;
        return $short_string;
    }
}

if (! function_exists('script_checker')) {
    function script_checker($string = '', $convert_string = true) {

        if($convert_string){
            return nl2br(htmlspecialchars(strip_tags($string)));
        }else{
            return $string;
        }

    }
}

if (!function_exists('currency')) {
    function currency($price = "")
    {
        return $price.'$';
    }
}

if (! function_exists('get_settings')) {
    function get_settings($type = "", $return_type = "") {
        $value = DB::table('settings')->where('type', $type)->value('description');
        if($return_type == "object"){
            return json_decode($value);
        }elseif($return_type){
            return json_decode($value, true);
        }else{
            return $value;
        }
    }
}

// for sending email 
if(!function_exists('send_mail')){
    function send_mail($user_id, $page, $parem3){
        Config(['mail.mailers.smtp.transport' => get_settings('smtp_protocol')]);
        Config(['mail.mailers.smtp.host' => get_settings('smtp_host')]);
        Config(['mail.mailers.smtp.port' => get_settings('smtp_port')]);
        Config(['mail.mailers.smtp.encryption' => get_settings('smtp_crypto')]);
        Config(['mail.mailers.smtp.username' => get_settings('smtp_user')]);
        Config(['mail.mailers.smtp.password' => get_settings('smtp_password')]);
        Config(['mail.from.address' =>get_settings('smtp_user')]);
        Config(['mail.from.name' => get_settings('site_name')]);
        $user = User::where('id', $user_id)->first();
        $page_data['name'] = $user->name;
        $page_data['code'] = $parem3;
        $data['to'] = $user->email;
        if($page == 'password_reset'){
            $page_data['page'] = $page;
            $data['subject'] = get_phrase('Password reset request');
            $page_data['massage'] = get_phrase('Thanks for using our application');
        }elseif($page == 'sign_up'){
            $page_data['page'] = $page;
            $data['subject'] = get_phrase('Account Verification');
            $page_data['massage'] = get_phrase('Thanks for signing up!');
        }elseif($page == 'payment_confirm'){
            $package = Package::where('id', $parem3)->first();
            $data['subject'] = get_phrase('Payment Successful');
            $page_data['page'] = $page;
            $page_data['massage'] = get_phrase('You successfully subscribe to our ').' '.$package->name.' '.get_phrase('Plan');
        }
        Mail::send('email_template', $page_data, function($massage) use ($data){
            $massage->to($data['to']);
            $massage->subject($data['subject']);
        });
    }
}

if(!function_exists('get_date')){
    function get_date($data){
        $data = date_create($data);
        return date_format($data,"d M Y");
    }
}

if (!function_exists('premium_user')) {
    function premium_user($user_id) {
        $user = User::where('id', $user_id)->first();
        $subscriber = Subscription::where('user_id', $user_id)->orderBy('id', 'DESC')->first();
        if(isset($subscriber->id) > 0 && $subscriber->status == 1){
            $second_in_month = cal_days_in_month(CAL_GREGORIAN,date('m'),date('Y')) * 86400;
            $monthly_subscription = strtotime($subscriber->created_at) + $second_in_month;
            if($monthly_subscription >= strtotime("now")){
                return 1;
            }else{
                return 0;
            }
        }else{
            return 0;
        }
    }
}

if(!function_exists('time_duration')){
    function time_duration($id, $type){
        if($type == 'movie'){
            $movie = Movie::where('id', $id)->first();
            $time = explode(':', $movie->duration);
            $hours = $time[0]*60;
            $minutes = $time[1]+$hours;
            $second = $time[2];
            echo $minutes.get_phrase('m')." ".$second.get_phrase('s');
        }elseif($type == 'series'){
            $season = Season::where('series', $id)->get();
            $time = array();
            foreach($season as $season){
                $episode = Episode::where('season', $season->id)->get();
                foreach($episode as $episode){
                    $duration = $episode->duration;
                    if(!in_array($duration, $time, true)){
                        array_push($time, $duration);
                    }
                }
            }
            $hours = array();
            $minutes = array();
            $seconds = array();
            foreach($time as $value){
                $time = explode(':', $value);
                if(!in_array($time[0], $hours, true)){
                    array_push($hours, $time[0]);
                }
                if(!in_array($time[1], $minutes, true)){
                    array_push($minutes, $time[1]);
                }
                if(!in_array($time[2], $seconds, true)){
                    array_push($seconds, $time[2]);
                }
            }
            $min = array_sum($hours)*60 + array_sum($minutes);
            $sec = array_sum($seconds);
            echo $min.get_phrase('m')." ".$sec.get_phrase('s');
        }elseif($type == 'episode'){
            $episode = Episode::where('id', $id)->first();
            $time = explode(':', $episode->duration);
            $hours = $time[0]*60;
            $minutes = $time[1]+$hours;
            $second = $time[2];
            echo $minutes.get_phrase('m')." ".$second.get_phrase('s');
        }
    }
}

if(!function_exists('get_price')){
    function get_price($data){
        $currency = Currency::where('code', get_settings('currency'))->first();
        if(get_settings('currency_position') == 'right'){
            echo $data.$currency->symbol;
        }elseif(get_settings('currency_position') == 'right_space'){
            echo $data.' '.$currency->symbol;
        }elseif(get_settings('currency_position') == 'left'){
            echo $currency->symbol.$data;
        }elseif(get_settings('currency_position') == 'left_space'){
            echo $currency->symbol.' '.$data;
        }
    }
}

if(!function_exists('promo_video')){
    function promo_video($data){
        $youtube_video_id = explode('youtu.be/', $data);
        return $youtube_video_id[1]??'';
    }
}

if(!function_exists('valid_subscription')){
    function valid_subscription($plan_id){
        return Subscription::where('plan_id', $plan_id)->where('user_id', get_user('id'))->orderBy('id', 'desc')->first();
    }
}

if (! function_exists('remove_js')) {
    function remove_js($description = '', $convert_string = false) {

        if ($convert_string == true) {
            $description = nl2br(htmlspecialchars($description));
        } else {
            //make script to string
            $description = str_replace("&lt;script&gt;", "", $description);
            $description = str_replace("&lt;/script&gt;", "", $description);

            //removing <script> tags
            $description = preg_replace('/<script\b[^>]*>(.*?)<\/script>/is', "", $description);
            $description = preg_replace("/[<][^<]*script.*[>].*[<].*[\/].*script*[>]/i", "", $description);

            //removing inline js events
            $description = preg_replace("/([ ]on[a-zA-Z0-9_-]{1,}=\".*\")|([ ]on[a-zA-Z0-9_-]{1,}='.*')|([ ]on[a-zA-Z0-9_-]{1,}=.*[.].*)/", "", $description);

            //removing inline js
            $description = preg_replace("/([ ]href.*=\".*javascript:.*\")|([ ]href.*='.*javascript:.*')|([ ]href.*=.*javascript:.*)/i", "", $description);
        }

        return $description;
    }
}
