<?php

namespace App\Http\Controllers\Admin\Users;

use App\Http\Controllers\Controller;
use App\Models\User;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use RealRashid\SweetAlert\Facades\Alert;

class UsersController extends Controller{
    // users list page
    public function index(){
        $page_data['users'] = User::where('user_type', 'user')->where('status', NULL)->paginate(10);
        return view('admin.users.index', $page_data);
    }

    // create user page
    public function create(){
        return view('admin.users.create');
    }

    // store user data
    public function store(Request $request){
        $validatedData = $request->validate([
            'name' => 'required|max:20',
            'email' => 'required|email|unique:users,email',
            'password' => 'required',
        ]);
        $data = array(
            'name' => $request->name,
            'email' => $request->email,
            'password' => Hash::make($request->password),
            'user_type' => 'user',
            'created_at' => Carbon::now(),
            'updated_at' => Carbon::now(),
        );
        $insert = User::insert($data);
        if($insert){
            $image_name = 0;
            $request_data = array(
                'name' => $request->name,
                'image' => $image_name
            );
            // create default user
            $data = array(
                'user1' => json_encode($request_data)
            );
            User::where('email', $request->email)->update($data);
            Alert::success(get_phrase('Success'), get_phrase('User Created Successfully'));
            return redirect()->back();
            
        }else{
            Alert::error(get_phrase('Retry'), get_phrase('Somthing wrong'));
            return redirect()->back();
           
        }
    } 

    // edit user page
    public function edit($id){
        $page_data['user_details'] = User::where('id', $id)->first();
        $user = User::where('id', $id)->first();
        return view('admin.users.edit', $page_data);
    }

    // update user data
    public function update(Request $request, $id){
        $validatedData = $request->validate([
            'name' => 'required|max:20',
            'email' => 'required',
        ]);
       
        $data = array(
            'name' => $request->name,
            'email' => $request->email,
            'updated_at' => Carbon::now(),
        );
        $update = User::where('id', $id)->update($data);
        if($update){
            Alert::success(get_phrase('Success'), get_phrase('User Updated Successfully'));
            return redirect()->back();
        }else{
            Alert::error(get_phrase('Retry'), get_phrase('Somthing wrong'));
            return redirect()->back();
           
        }
    }

    // delete user data
    public function delete($id){
        $delete = User::where('id', $id)->delete();
        if($delete){
            Alert::info(get_phrase('Success'), get_phrase('User Deleted Successfully'));
            return redirect()->back();
        }else{
            Alert::error(get_phrase('Retry'), get_phrase('Somthing wrong'));
            return redirect()->back();
        }
    }


    // User Ban
    public function adminUserBan($id)
    {
        $page_data['user_details'] = User::where('id', $id)->first();
        $user = User::where('id', $id)->first();
        return view('admin.users.ban', $page_data);
    }

    public function BanList(){
        $page_data['users'] = User::where('user_type', 'user')->where('status', 1)->paginate(10);
        return view('admin.users.ban_list', $page_data);
    }


    public function UserbanUpdate(Request $request, $id){
       
        $data = array(
            'status' => 1,
            'ban_description' => $request->ban_description,
            'updated_at' => Carbon::now(),
        );
        $update = User::where('id', $id)->update($data);
        if($update){
            Alert::success(get_phrase('Success'), get_phrase('User Ban Successfully'));
            return redirect()->back();
        }else{
            Alert::error(get_phrase('Retry'), get_phrase('Somthing wrong'));
            return redirect()->back();
           
        }
    }

    public function adminUserUnban($id)
    {
        $user = User::find($id);
        $user['status']= NULL ;
        $user['ban_description']= NULL ;
        $user['ban_request']= NULL ;
        $user['ban_user_description']= NULL ;
        $user->save();
        Alert::info(get_phrase('Success'), get_phrase('User Ban Remove Successfully'));
        return redirect()->back();
    }










}
