<?php

namespace App\Http\Controllers\Frontend;

use App\Http\Controllers\Controller;
use App\Models\Actor;
use App\Models\Category;
use App\Models\Director;
use App\Models\Faq;
use App\Models\Genre;
use App\Models\Movie;
use App\Models\Package;
use App\Models\Series;
use App\Models\Subscription;
use App\Models\User;
use Illuminate\Http\Request;

class HomepageController extends Controller{
    // home page view
    public function index(){
        $page_data['packages'] = Package::get();
        $page_data['featured_movies'] = Movie::where('featured', 'yes')->limit(7)->get();
        $page_data['trending_movies'] = Movie::where('is_trending', 'yes')->limit(4)->get();
        $page_data['top_reated_movies'] = Movie::whereBetween('rating', [4, 5])->limit(4)->get();
        $page_data['popular_shows'] = Series::where('popular_shows', 'yes')->limit(4)->get();
        // $page_data['genre_section'] = Genre::where('homepage_view', 1)->get();
        // $page_data['category_section'] = Category::where('homepage_view', 1)->get();
        return view('frontend.homepage', $page_data);
    }

    // homepage view
    public function homepage(){
        return view('frontend.homepage');
    }

    // packages
    public function packages(){
        $page_data['packages'] = Package::where('status', 'Active')->get();
        return view('frontend.packages', $page_data);
    }

    // search result search
    public function search(Request $request, $id, $type, $idan){
        $page_data['actor'] = Actor::get();
        $page_data['actor'] = Actor::get();
        $page_data['director'] = Director::get();
        $page_data['genre'] = Genre::get();
        $page_data['category'] = Category::get();
        if($request->search){
            $page_data['all_movies'] = Movie::where('title', 'like', "%{$request->search}%")->paginate(12);
            $page_data['all_series'] = Series::where('title', 'like', "%{$request->search}%")->paginate(12);
            $page_data['keyword'] = $request->search;
        }elseif($type == ''){
            $page_data['all_movies'] = Movie::where('title', 'like', "%{$request->search}%")->paginate(12);
            $page_data['all_series'] = Series::where('title', 'like', "%{$request->search}%")->paginate(12);
            $page_data['keyword'] = get_phrase('All Videos');
        }elseif($type == 'movie'){
            $page_data['all_movies'] = Movie::paginate(12);
            $page_data['all_series'] = array();
            $page_data['keyword'] = get_phrase('Movies');
        }elseif($type == 'series'){
            $page_data['all_series'] = Series::paginate(12);
            $page_data['all_movies'] = array();
            $page_data['keyword'] = get_phrase('Series');
        }elseif($type == 'category'){
            $page_data['all_movies'] = Movie::where('title', 'like', "%{$request->search}%")->where('category', $id)->paginate(12);
            $page_data['all_series'] = Series::where('title', 'like', "%{$request->search}%")->where('category', $id)->paginate(12);
            $category = Category::where('id', $id)->first();
            $page_data['keyword'] = $category->name;
        }elseif($type == 'genre'){
            $page_data['all_movies'] = Movie::where('title', 'like', "%{$request->search}%")->where('genre', $id)->paginate(12);
            $page_data['all_series'] = Series::where('title', 'like', "%{$request->search}%")->where('genre', $id)->paginate(12);
            $genre = Genre::where('id', $id)->first();
            $page_data['keyword'] = $genre->name;
        }
        $page_data['factor'] = $request->actor ? $request->actor : 'all';
        $page_data['fdirector'] = $request->director ? $request->director : 'all';
        $page_data['fgenre'] = $request->genre ? $request->genre : 'all';
        $page_data['fcategory'] = $request->category ? $request->category : 'all';
        $page_data['fyear'] = $request->year;
        return view('frontend.video_filter', $page_data);
    }

    public function sidebar_filter(Request $request){
        $page_data['actor'] = Actor::get();
        $page_data['director'] = Director::get();
        $page_data['genre'] = Genre::get();
        $page_data['category'] = Category::get();
        if(strtolower($request->keyword) == 'movies'){
            $query = Movie::query();
        }else{
            $query = Series::query();
        }
        if($request->actor != 'all'){
            $query = $query->where('actor', 'like', "%{$request->actor}%");
        }
        if($request->director != 'all'){
            $query = $query->where('director', $request->director);
        }
        if($request->genre != 'all'){
            $query = $query->where('genre', $request->genre);
        }
        if($request->category != 'all'){
            $query = $query->where('category', $request->category);
        }
        if($request->year != 'all'){
            $query = $query->where('year', $request->year);
        }
        if(strtolower($request->keyword) == 'movies'){
            $page_data['all_movies'] = $query->paginate(12);
            $page_data['all_series'] = array();
        }else{
            $page_data['all_series'] = $query->paginate(12);
            $page_data['all_movies'] = array();
        }
        $page_data['keyword'] = $request->keyword;
        $page_data['factor'] = $request->actor ? $request->actor : 'all';
        $page_data['fdirector'] = $request->director ? $request->director : 'all';
        $page_data['fgenre'] = $request->genre ? $request->genre : 'all';
        $page_data['fcategory'] = $request->category ? $request->category : 'all';
        $page_data['fyear'] = $request->year;
     
        return view('frontend.video_filter', $page_data);
    }

    // faq page view
    public function faq(){
        $page_data['faq'] = Faq::get();
        return view('frontend.faq', $page_data);
    }

    // privecy policy page view 
    public function privacy_policy(){
        $page_data['privacy_policy'] = get_settings('privacy_policy');
        return view('frontend.privacy_policy', $page_data);
    }

    // privecy policy page view 
    public function refund_policy(){
        $page_data['refund_policy'] = get_settings('refund_policy');
        return view('frontend.refund_policy', $page_data);
    }

    // invoice view
    public function invoice($id){
        $page_data['subscription'] = Subscription::where('id', $id)->first();
        $page_data['plan'] = Package::where('id', $page_data['subscription']->plan_id)->first();
        return view('frontend.invoice', $page_data);
    }

    // user subsription cancl
    public function subscription_cancel(){
        $exist_subscription = User::where('id', get_user('id'))->first();
        if($exist_subscription->plan){
            $data = array (
                'plan' => 0
            );
            $update = User::where('id', get_user('id'))->update($data);
            if($update){
                toast(get_phrase('Cancle Successfully'),'success');
                return redirect()->back();
            }else{
                toast(get_phrase('Somthing wrong'), 'error');
                return redirect()->back();
            }
        }else{
            toast(get_phrase('You dont have any plan yet'), 'error');
            return redirect()->back();
        }
    }

    public function theme_color(Request $request){
        $data['theme_color'] = $request->theme;
        $request->session()->put('theme_color', (object)$data);
    }


    // User Ban Request
    public function UserBanRequest(Request $request , $id){
        $data = array(
            'ban_request' => 1,
            'ban_user_description' => $request->ban_user_description,
        );
        $update = User::where('id', $id)->update($data);
        if($update){
            toast(get_phrase('Ban Remove Request Send Successfully'),'success');
            return redirect()->back();
        }else{
            toast(get_phrase('Something went wrong'),'error');
            return redirect()->back();
           
        }
    }
    

  
}
